<?php
    /*
     * Part of the conditional for handling options updates
     */
    if($_POST['srslide_save_hidden'] == 'Y') {
        $errors = array();

        // Set the show logo option
        ($_POST['srslide_show_logo'] == 'on') ? update_option('srslide_show_logo',true) : update_option('srslide_show_logo',false);

        // Set the recommend pages option
        ($_POST['srslide_use_pages'] == 'on') ? update_option('srslide_use_pages',true) : update_option('srslide_use_pages',false);

        $header_length = strlen($_POST['srslide_header_text']);
        if ($header_length < 1 or $header_length > 30) {
            array_push($errors, "Header text cannot be more than 30 characters.");
        } else {
            update_option('srslide_header_text', strtoupper($_POST['srslide_header_text']) );
        }

        $api_key_length = strlen($_POST['srslide_api_key']);
        if ($api_key_length != 32) {
            array_push($errors, "API Key should be 32 characters. Please double check your entry.");
        } else {
            update_option('srslide_api_key', $_POST['srslide_api_key']);
        }

        // Convert the style settings into a hash and save it
        // TODO Write comparison function to if styles that need to be sent to CDN haven't been changed. Skip CURL if there was no change
        $style_hash = create_style_hash($_POST);
        update_option('srslide_styles',$style_hash);
        $style_error = update_slide_styles();
        if ($style_error != "OK") {
            array_push($errors, $style_error);
        }

        // Save if we are error free or print the errors
        if (count($errors) == 0) {
          ?>
          <div class="updated"><p><strong><?php _e('Options saved. If you shifted The Slide position or adjusted the link color, it could take up to 15 minutes for your changes to take effect.', 'srslide'); ?></strong></p></div>
          <?php
        } else {
          ?>
          <div class="updated"><p><strong><?php _e('You have the following errors:', 'srslide'); ?></strong></p></div>

          <?php
              foreach ($errors as $i => $value) {
                  ?>
                  <div class="updated"><p style='margin-left:10px;'><strong><?php echo $value; ?></strong></p></div>
                  <?php
              }
        }

    /*
     * Part of the conditional for handling a registration
     */
    } else if ($_POST['srslide_register_hidden'] == 'Y') {

        // Setup the encoded params from the $_POST
        $encoded_params = '';
        foreach($_POST as $name => $value) {
            // Only pass vars that start with srslide_sr
            if (!preg_match('/^srslide_sr_.+/',$name)) { continue; }
            $encoded_params .= urlencode($name).'='.urlencode($value).'&';
        }

        // Get the blog name
        $encoded_params .= 'account_name='.urlencode(get_option('blogname')).'&';
        // Get the site URL
        $encoded_params .= 'website='.urlencode(get_option('siteurl')).'&';
        $encoded_params .= 'ts='.(int)gmdate('U').'&';

        // Remove the last '&'
        $encoded_params = substr($encoded_params, 0, strlen($encoded_params)-1);

        // Curl call for registration
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, "https://www.simplereach.com/publisher/wp_create");
        curl_setopt($curl, CURLOPT_POST, count(explode('&',$encoded_params)));
        curl_setopt($curl, CURLOPT_POSTFIELDS, $encoded_params);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        $curl_resp = curl_exec($curl);
        curl_close($curl);

        // Decode the JSON
        $resp = json_decode($curl_resp);

        if ($resp->{'success'}) {

            // Save the PID and the API Key to Wordpress
            update_option('srslide_pid',$resp->{'success'});
            if ($resp->{'api_key'}) {
                update_option('srslide_api_key',$resp->{'api_key'});
            }

            // Set some defaults only now that we have a registration
            set_srslide_defaults($_POST);
            ?>
                <div id="message" class="updated below-h2"><p>
                    <?php _e('Congratulations, your SimpleReach account has been successfully created!', 'srslide') ?>
                </p></div>
            <?php
        } else {
            ?>
                <div id="message" class="updated below-h2"><p>
            <?php
                _e("We were not able to register you: ", 'srslide');
                if ($resp->{'error'} == 'Invalid Domain') {
                    _e("This domain has already been registered. Please contact <a href='mailto:support@simplereach.com'>SimpleReach support</a> if you believe you have received this message in error.", 'srslide');
                } else if ($resp->{'error'} == 'Incorrect Timestamp') {
                    _e("There was an error while you were attempting to register. Please try again or contact <a href='mailto:support@simplereach.com'>SimpleReach support</a> if you believe you have received this message in error.", 'srslide');
                } else if ($resp->{'error'} == 'Invalid Password') {
                    _e("The user name that you are attempting to register with already exists, but the password you entered was incorrect. Please try again or contact <a href='mailto:support@simplereach.com'>SimpleReach support</a> if you believe you have received this message in error.", 'srslide');
                } else {
                    _e("An unknown error has been encountered. Please try again or contact <a href='mailto:support@simplereach.com'>SimpleReach support</a>.", 'srslide');
                }
            ?>
                </p></div>
            <?php
            update_option('srslide_registered',false);
        }
    }

    // Is the publisher a registered SimpleReach user
    $sr_is_registered = get_option('srslide_registered');
?>

<div class="srslide_admin">
    <?php echo "<h2>" . __('The Slide by SimpleReach', 'srslide') . "</h2>"; ?>

    <?php if ($sr_is_registered) {
        // Part of our normal page display
        $srpid = get_option('srslide_pid');
        $srlogin = get_option('srslide_sr_login');
        $srslide_header_text = get_option('srslide_header_text');
        $srslide_style = get_option('srslide_styles');
        $srslide_api_key = get_option('srslide_api_key');
        $debug_info = create_debug_info();

        $slide_show_logo = 'CHECKED=CHECKED';
        if (get_option('srslide_show_logo') == false) {
          $slide_show_logo = '';
        }

        $slide_use_pages = 'CHECKED=CHECKED';
        if (get_option('srslide_use_pages') == false) {
          $slide_use_pages = '';
        }
    ?>

        <div class="overview">
            <p>
                <?php _e("You're registered!", 'srslide'); ?>
            </p>
            <p>
                <?php _e("Use your email/password to LOG-IN to ", 'srslide'); ?><a href="https://www.simplereach.com">simplereach.com</a> <?php _e(" to access your analytics/reporting dashboard", 'srslide'); ?>.
            </p>
            <p>
                <?php _e("If you have any questions, please don't hesitate to", 'srslide'); ?>
                <a href="https://www.simplereach.com/contact?r=support&e=<?php echo urlencode($srlogin); ?>&debug_info=<?php echo urlencode($debug_info); ?>#reach-out"><?php _e("contact us", 'srslide'); ?></a>!
            </p>
        </div>

      <hr />

        <?php echo "<h3>" . __('Display Settings', 'srslide') . "</h3>"; ?>

        <div id="srslide_controls">
            <form name="srslide_form" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">

                <input type="hidden" name="srslide_save_hidden" value="Y">

                <table border="2">
                    <tr>
                        <td valign="top">
                            <?php _e("Edit Header (Max 30 char):", 'srslide'); ?>
                        </td>
                        <td colspan="2">
                                <input type="textbox" name="srslide_header_text" value='<?php echo $srslide_header_text; ?>' /><br />
                                <span class="srslide_minitext"><?php _e("All letters will be uppercase.", 'srslide'); ?> &nbsp; (<?php _e("Default: RECOMMENDED FOR YOU", 'srslide'); ?>)</span>
                        </td>
                    </tr>
                    <tr>
                        <td colspan="3">
                            <div>
                                <div class="link_color_label"><?php _e("Link Color:", 'srslide'); ?></div>
                                <?php
                                    $srslide_default_link_colors = array('#FE3F10', '#3B5998', '#CC0000');
                                    foreach ($srslide_default_link_colors as $color) {
					$colorChecked = ($srslide_style['link']['color'] == $color) ? __("CHECKED", 'srslide') : '';
                                ?>
                                    <div class="link_color_selector">
                                        <input type="radio" name="srslide_style_link_color" value="<?php echo $color; ?>" <?php echo $colorChecked; ?>>
                                        <div style="background-color:<?php echo $color; ?>;"></div>
                                    </div>
                                <?php
                                    }
                                ?>
                                    <input class="custom_color" type="radio" name="srslide_style_link_color" value="other" <?php if (!in_array($srslide_style['link']['color'],$srslide_default_link_colors)) { echo "CHECKED"; } ?>> &nbsp;
					<input type="textbox" name="srslide_style_link_color_text" value='<?php if (!in_array($srslide_style['link']['color'],$srslide_default_link_colors)) { echo "{$srslide_style['link']['color']}"; } ?>' />
                                    <div class="custom_color_label" style='float:left;'><?php _e("hex code ", 'srslide'); ?><br /><span class="srslide_minitext"><?php _e("(eg #FE3F10):", 'srslide'); ?></span></div>
                                </div>
                            </div>
                        </td>
                    </tr>

                    <tr>
                        <td colspan='3'>
                            <span><?php _e("Shift The Slide up by: ", 'srslide'); ?></span>
                            <select name='srslide_style_element_bottom'>
				<?php
					$shiftUpValues = array('0px', '30px', '40px', '50px', '60px');
					foreach ($shiftUpValues as $shiftUpValue) {
						$shiftUpValueSelected = ($srslide_style['element']['bottom'] == $shiftUpValue) ? __('SELECTED', 'srslide') : '';
						print '<option value="'.$shiftUpValue.'" '.$shiftUpValueSelected .'>'.$shiftUpValue.'</option>';
					}
				?>
                            </select>
                        </td>
                    </tr>

                    <tr>
                        <td colspan="3">
                                <input type="checkbox" name="srslide_use_pages" <?php echo $slide_use_pages; ?> />
                                <?php _e("Also show The Slide on Pages", 'srslide'); ?><br />
                                <span class="srslide_minitext" style='margin-left:18px;'>
                                    <?php _e("Default setting is to show The Slide only on ", 'srslide'); ?>
                                    <em><?php _e("Posts", 'srslide'); ?></em>
                                </span>
                        </td>
                    </tr>

                    <tr>
                        <td colspan="3">
                            <input type="checkbox" name="srslide_show_logo" <?php echo $slide_show_logo; ?> />
                            <span><?php _e("Display The Slide logo (increases engagement)", 'srslide'); ?></span>
                        </td>
                    </tr>
                </table>

                <input type="submit" name="Submit" value="<?php _e('Save', 'srslide'); ?>" />
                <hr />

                <?php echo "<h3>" . __('Account Settings', 'srslide') . "</h3>"; ?>

                    <table>
                    <tr>
                        <td valign="top">
                            <div><?php _e("API Key:", 'srslide'); ?></div>
                        </td>
                        <td colspan="2">
                                <input type="textbox" name="srslide_api_key" value="<?php echo $srslide_api_key; ?>" /><br />
                                <span class="srslide_minitext"><?php _e("Warning: Do not change unless you know what you are doing.", 'srslide'); ?></span>
                        </td>
                    </tr>
                </table>

            <input type="submit" name="Submit" value="<?php _e('Save', 'srslide'); ?>" />
            </form>
        </div>

        <div id="srslide_example">
            <img src="/wp-content/plugins/srslide_wordpress/screenshot-1.png">
        </div>

    <?php
        } else {
        $slide_show_logo = 'CHECKED=CHECKED';
    ?>

	<div id="srslide_register">
        <p><strong><?php _e("Register for a SimpleReach account. If you have already registered at simplereach.com, enter your login information below.", 'srslide') ?></strong></p>
        <form name="srslide_form" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
          <input type="hidden" name="srslide_register_hidden" value="Y">

            <table cellspacing="8">
              <tr>
                <td class="label"><?php _e("Email: " , 'srslide'); ?></td>
                <td><input type="text" name="srslide_sr_login" value="<?php echo $sr_login; ?>" size="35"></td>
                <td><?php _e(" ex: user@example.com" , 'srslide'); ?></td>
              </tr>

              <tr>
                <td class="label"><?php _e("Password: " , 'srslide'); ?></td>
                <td><input type="password" name="srslide_sr_pass" value="<?php echo $sr_password; ?>" size="35"></td>
                <td><?php _e(" ex: secretpass" , 'srslide'); ?></td>
              </tr>

              <tr>
                <td>&nbsp;</td>
                <td colspan="2" class="srslide_minitext">
                  <input type="checkbox" name="srslide_show_logo" <?php echo $slide_show_logo; ?> />
                  <?php _e("I would like to display The Slide logo (increases engagement)", 'srslide'); ?>
                </td>
              </tr>

              <tr>
                <td>&nbsp;</td>
                <td style='text-align:right'><input type="submit" name="Submit" value="<?php _e('Register', 'srslide'); ?>" /></td>
                <td>&nbsp;</td>
              </tr>
            </table>

        </form>
	</div>

    <?php } ?>
</div>
